==> hikari-2.0.0.dev106.tar.gz: hikari-2.0.0.dev106/hikari/impl/__init__.py <==
# -*- coding: utf-8 -*-
# cython: language_level=3
# Copyright (c) 2020 Nekokatt
# Copyright (c) 2021-present davfsa
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Basic implementations of application components.

These components implement the interfaces in `hikari.api` to provide the
baseline functionality. For most applications that do not have bespoke
performance or structural requirements, you will want to use these
implementations.
"""

from __future__ import annotations

from hikari.impl.bot import *
from hikari.impl.buckets import *
from hikari.impl.cache import *
from hikari.impl.entity_factory import *
from hikari.impl.event_manager import *
from hikari.impl.event_manager_base import *
from hikari.impl.interaction_server import *
from hikari.impl.rate_limits import *
from hikari.impl.rest import *
from hikari.impl.rest_bot import *
from hikari.impl.special_endpoints import *
from hikari.impl.voice import *

==> hikari-2.2.0.tar.gz: hikari-2.2.0/hikari/impl/__init__.py <==
# cython: language_level=3
# Copyright (c) 2020 Nekokatt
# Copyright (c) 2021-present davfsa
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
"""Basic implementations of application components.

These components implement the interfaces in [`hikari.api`][] to provide the
baseline functionality. For most applications that do not have bespoke
performance or structural requirements, you will want to use these
implementations.
"""

from __future__ import annotations

from hikari.impl.buckets import *
from hikari.impl.cache import *
from hikari.impl.config import *
from hikari.impl.entity_factory import *
from hikari.impl.event_manager import *
from hikari.impl.event_manager_base import *
from hikari.impl.gateway_bot import *
from hikari.impl.interaction_server import *
from hikari.impl.rate_limits import *
from hikari.impl.rest import *
from hikari.impl.rest_bot import *
from hikari.impl.shard import *
from hikari.impl.special_endpoints import *
from hikari.impl.voice import *
